@@ -84,9 +84,10 @@
 '''
 from __future__ import absolute_import
 
-import six
 import types
 
+import six
+
 from testbase import logger
 from testbase.conf import settings
 from testbase.testcase import TestCase
@@ -102,33 +103,32 @@ def translate_bad_char4exclude_keys(data_key):
     return data_key
 
 
-
 class DataDrive(object):
-    '''数据驱动类修饰器，标识一个测试用例类使用数据驱动
-    '''
+    """数据驱动类修饰器，标识一个测试用例类使用数据驱动"""
 
     def __init__(self, case_data):
-        '''构造函数
+        """构造函数
 
         :param case_datas: 数据驱动测试数据集
         :type case_datas: list/tuple/dict
-        '''
+        """
         self._case_data = case_data
 
     def __call__(self, testcase_class):
-        '''修饰器
+        """修饰器
 
         :param testcase_class: 要修饰的测试用例
         :type testcase_class: TestCase
-        '''
+        """
         if not issubclass(testcase_class, TestCase):
-            raise TypeError('data driver decorator cannot be applied to non-TestCase type')
+            raise TypeError(
+                "data driver decorator cannot be applied to non-TestCase type"
+            )
         testcase_class.__qtaf_datadrive__ = self
         return testcase_class
 
     def __iter__(self):
-        '''遍历全部的数据名
-        '''
+        """遍历全部的数据名"""
         if isinstance(self._case_data, types.GeneratorType):
             self._case_data = list(self._case_data)
         if isinstance(self._case_data, list) or isinstance(self._case_data, tuple):
@@ -139,8 +139,7 @@ class DataDrive(object):
                 yield it
 
     def __getitem__(self, name):
-        '''获取对应名称的数据
-        '''
+        """获取对应名称的数据"""
         return self._case_data[name]
 
     def __len__(self):
@@ -148,24 +147,24 @@ class DataDrive(object):
 
 
 def is_datadrive(obj):
-    '''是否为数据驱动用例
+    """是否为数据驱动用例
 
     :param obj: 测试用例或测试用例类
     :type obj: TestCase/type
 
     :returns boolean
-    '''
-    return hasattr(obj, '__qtaf_datadrive__')
+    """
+    return hasattr(obj, "__qtaf_datadrive__")
 
 
 def get_datadrive(obj):
-    '''获取对应用例的数据驱动
+    """获取对应用例的数据驱动
 
     :param obj: 测试用例或测试用例类
     :type obj: TestCase/type
 
     :returns DataDrive
-    '''
+    """
     return obj.__qtaf_datadrive__
 
 
@@ -196,8 +195,7 @@ def _translate_bad_char4exclude_keys(data_key):
 
 
 def load_datadrive_tests(cls, name=None, exclude_data_key=None, attrs=None):
-    '''加载对应数据驱动测试用例类的数据驱动用例
-    '''
+    """加载对应数据驱动测试用例类的数据驱动用例"""
     if is_datadrive(cls):
         dd = get_datadrive(cls)
     else:
@@ -205,21 +203,24 @@ def load_datadrive_tests(cls, name=None, exclude_data_key=None, attrs=None):
             raise RuntimeError("DATA_DRIVE is not set to True")
 
         from testbase.loader import TestDataLoader
+
         dd = TestDataLoader().load()
 
     if name:
         if name in dd:
-            drive_data = {name : dd[name]}
+            drive_data = {name: dd[name]}
         else:
             drive_value = _get_translated_in_datadrive(name, dd)
-            drive_data = {name : drive_value}
+            drive_data = {name: drive_value}
     else:
         drive_data = dd
 
     if exclude_data_key is None:
         exclude_data_key = []
 
-    exclude_data_key = [_translate_bad_char4exclude_keys(item) for item in exclude_data_key]
+    exclude_data_key = [
+        _translate_bad_char4exclude_keys(item) for item in exclude_data_key
+    ]
 
     tests = []
     for item in drive_data:
@@ -235,7 +236,10 @@ def load_datadrive_tests(cls, name=None, exclude_data_key=None, attrs=None):
         casedata_name = item
         if has_bad_char(item):
             casedata_name = translate_bad_char(item)
-            warn_msg = "[WARNING]%r's drive data key should use \"%s\" instead of \"%s\"" % (cls, casedata_name, item)
+            warn_msg = (
+                '[WARNING]%r\'s drive data key should use "%s" instead of "%s"'
+                % (cls, casedata_name, item)
+            )
             logger.warn(warn_msg)
 
         if isinstance(testdata, dict) and "__attrs__" in testdata:
@@ -251,4 +255,3 @@ def load_datadrive_tests(cls, name=None, exclude_data_key=None, attrs=None):
 
         tests.append(cls(testdata, casedata_name, new_attrs))
     return tests
-
