@@ -17,6 +17,7 @@
 """
 from __future__ import absolute_import
 
+import inspect
 import os
 import sys
 import json
@@ -212,6 +213,7 @@ class TestCase(object):
         "begintime",
         "endtime",
         "duration",
+        "name",
     ]
 
     def __init__(self, testdata=None, testdataname=None, attrs=None):
@@ -232,6 +234,7 @@ class TestCase(object):
         self.__resmgr = None
         self.__share_data_mgr = None
         self.__test_doc = None
+        self.__current_stage = None
 
         # 参数相关
         self.__params_definitions = {}  # add_params原始的用例参数数据
@@ -380,6 +383,14 @@ class TestCase(object):
     def dynamic_params(self):
         return self.__dynamic_params
 
+    @property
+    def current_stage(self):
+        return self.__current_stage
+
+    @current_stage.setter
+    def current_stage(self, current_stage):
+        self.__current_stage = current_stage
+
     def get_test_extra_properties(self):
         var_dicts = {}
         for k, v in getmembers(self):
@@ -905,7 +916,10 @@ class TestCaseRunner(ITestCaseRunner):
         for key in dir(cls):
             item = getattr(cls, key)
             if isinstance(item, (types.MethodType, types.FunctionType)):
-                rewriter.rewrite(item)
+                item_source_file = inspect.getsourcefile(item)
+                cls_source_file = inspect.getsourcefile(cls)
+                if item_source_file == cls_source_file:
+                    rewriter.rewrite(item)
 
     def _walk_bases(self, test_case):
         """遍历所有基类，进行相应的处理"""
@@ -917,7 +931,7 @@ class TestCaseRunner(ITestCaseRunner):
             new_bases = set()
             for base_cls in bases:
                 self._single_methods_mapping(base_cls)
-                self._rewrite_assert(cur_cls)
+                self._rewrite_assert(base_cls)
                 new_bases = new_bases.union(set(base_cls.__bases__))
             bases = new_bases
 
@@ -989,6 +1003,7 @@ class TestCaseRunner(ITestCaseRunner):
 
                 if isinstance(it, str):
                     try:
+                        self._testcase.current_stage = it
                         if it in ["init_test", "initTest"]:
                             getattr(self._testcase, it)(self._testresult)
                         else:
